@@ -103,6 +103,7 @@ main(argc, argv)
 	int master_field = -1;
 	int io_error_field = -1;
 	int sql_error_field = -1;
+	int slave_sql_running_state_field = -1;
 
 	while ((fl = getopt(argc, argv, "t:w:c:f:h:P:u:p:S:")) != -1) {
 		switch(fl) {
@@ -203,6 +204,11 @@ retry:
 			sql_error_field = i;
 			continue;
 		}
+
+		if (strcmp(mf->name, "Slave_SQL_Running_State") == 0) {
+			slave_sql_running_state_field = i;
+			continue;
+		}
 	}
 
 	if (sync_delay_field < 0 || sync_delay_field >= mysql_field_count(m)) {
@@ -246,6 +252,13 @@ retry:
 				sleep(1);
 				goto retry;
 			}
+		} else if (ml[slave_sql_running_state_field] != NULL &&
+			   strstr(ml[slave_sql_running_state_field],
+				  "Slave has read all relay log") != NULL) {
+			sync_delay = 0;
+			(void)snprintf(status_str, sizeof(status_str), 
+				       "%ds behind %s master.",
+				       sync_delay, ml[master_field]);
 		} else {
 			sync_delay = INT_MAX;
 			(void)snprintf(status_str, sizeof(status_str), 
